@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -214,7 +214,7 @@ fitted_PSF **peaker(fits *fit, int layer, starFinder *sf, rectangle *area) {
 					 *  slows down the algorithm too much 
 					 * To fit the angle, set the 3rd parameter to TRUE */
 					fitted_PSF *cur_star = psf_global_minimisation(z, bg, layer,
-							FALSE);
+							FALSE, FALSE);
 					if (cur_star) {
 						psf_update_units(fit, &cur_star);
 						if (is_star(cur_star, sf)) {
@@ -269,7 +269,7 @@ fitted_PSF *add_star(fits *fit, int layer, int *index) {
 	gboolean already_found = FALSE;
 
 	*index = -1;
-	result = psf_get_minimisation(&gfit, layer, &com.selection);
+	result = psf_get_minimisation(&gfit, layer, &com.selection, FALSE);
 	if (!result)
 		return NULL;
 	/* We do not check if it's matching with the "is_star()" criteria.
@@ -347,7 +347,8 @@ int compare_stars(const void* star1, const void* star2) {
 }
 
 void sort_stars(fitted_PSF **stars, int total) {
-	qsort(*(&stars), total, sizeof(fitted_PSF*), compare_stars);
+	if (*(&stars))
+		qsort(*(&stars), total, sizeof(fitted_PSF*), compare_stars);
 }
 
 void FWHM_average(fitted_PSF **stars, float *FWHMx, float *FWHMy, int max) {
