@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -29,6 +29,7 @@
 #include "core/siril.h"
 #include "core/proto.h"
 #include "algos/colors.h"
+#include "io/sequence.h"
 #include "io/single_image.h"
 #include "gui/PSF_list.h"
 #include "gui/callbacks.h"
@@ -446,6 +447,11 @@ void on_filechooser_file_set(GtkFileChooserButton *widget, gpointer user_data) {
 	if ((retval = read_single_image(filename, &layers[layer]->the_fit, NULL))) {
 		gtk_label_set_text(layers[layer]->label, _("ERROR"));
 	} else {
+		/* Force first tab to be Red and not B&W if an image was already loaded */
+		GtkNotebook* Color_Layers = GTK_NOTEBOOK(gtk_builder_get_object(builder, "notebook1"));
+		GtkWidget *page = gtk_notebook_get_nth_page(Color_Layers, RED_VPORT);
+		gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(Color_Layers), page, _("Red channel"));
+
 		if (number_of_images_loaded() > 1 &&
 				(gfit.rx != layers[layer]->the_fit.rx ||
 				 gfit.ry != layers[layer]->the_fit.ry)) {
