@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -28,13 +28,13 @@
 #include <unistd.h>
 #include <sys/time.h>
 #include <sys/types.h>
-#include <sys/wait.h>
 #include <dirent.h>
 #include "core/siril.h"
 #include "core/proto.h"
 #include "core/processing.h"
 #include "io/conversion.h"
 #include "io/films.h"
+#include "io/sequence.h"
 #include "io/ser.h"
 #include "gui/callbacks.h"
 #include "algos/demosaicing.h"
@@ -569,12 +569,16 @@ static gpointer convert_thread_worker(gpointer p) {
 			struct film_struct film_file;
 			if (film_open_file(src_filename, &film_file) != FILM_SUCCESS) {
 				siril_log_message(_("Error while opening film %s, aborting.\n"), src_filename);
+				clearfits(fit);
+				free(fit);
 				break;
 			}
 			if (convflags & CONVMULTIPLE) {
 				if (ser_create_file(create_sequence_filename(indice++, dest_filename, 128),
 							ser_file, TRUE, NULL)) {
 					siril_log_message(_("Creating the SER file failed, aborting.\n"));
+					clearfits(fit);
+					free(fit);
 					goto clean_exit;
 				}
 			}
@@ -583,6 +587,8 @@ static gpointer convert_thread_worker(gpointer p) {
 				if (film_read_frame(&film_file, frame, fit) != FILM_SUCCESS) {
 					siril_log_message(_("Error while reading frame %d from %s, aborting.\n"),
 							frame, src_filename);
+					clearfits(fit);
+					free(fit);
 					goto clean_exit;
 				}
 
@@ -592,12 +598,16 @@ static gpointer convert_thread_worker(gpointer p) {
 						keep_first_channel_from_fits(fit);
 					if (ser_write_frame_from_fit(ser_file, fit, frame)) {
 						siril_log_message(_("Error while converting to SER (no space left?)\n"));
+						clearfits(fit);
+						free(fit);
 						goto clean_exit;
 					}
 				} else {
 					g_snprintf(dest_filename, 128, "%s%05d", destroot, indice++);
 					if (save_to_target_fits(fit, dest_filename)) {
 						siril_log_message(_("Error while converting to FITS (no space left?)\n"));
+						clearfits(fit);
+						free(fit);
 						goto clean_exit;
 					}
 				}
