@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -28,6 +28,7 @@
 
 #include "core/siril.h"
 #include "core/proto.h"
+#include "io/sequence.h"
 #include "gui/callbacks.h"
 
 static char *MIPSHI[] = {"MIPS-HI", "CWHITE", NULL };
@@ -50,6 +51,23 @@ static char *Exposure[] = { "EXPTIME", "EXPOSURE", NULL };
 	} while ((keyword[__iter__]) && (__status__ > 0)); \
 }
 
+static void read_fits_date_obs_header(fits *fit) {
+	int status = 0;
+	fits_read_key(fit->fptr, TSTRING, "DATE-OBS", &(fit->date_obs), NULL, &status);
+
+	status = 0;
+	char ut_start[FLEN_VALUE];
+	/** Case seen in some FITS files. Needed to get date back in SER conversion **/
+	fits_read_key(fit->fptr, TSTRING, "UT-START", &ut_start, NULL,
+				&status);
+	if (ut_start[0] != '\0' && fit->date_obs[2] == '/') {
+		int year, month, day;
+		sscanf(fit->date_obs, "%02d/%02d/%04d", &day, &month, &year);
+		g_snprintf(fit->date_obs, sizeof(fit->date_obs), "%04d-%02d-%02dT%s",
+				year, month, day, ut_start);
+	}
+}
+
 /* reading the FITS header to get useful information */
 static void read_fits_header(fits *fit) {
 	/* about the status argument: http://heasarc.gsfc.nasa.gov/fitsio/c/c_user/node28.html */
@@ -97,9 +115,7 @@ static void read_fits_header(fits *fit) {
 	fits_read_key(fit->fptr, TSTRING, "BAYERPAT", &(fit->bayer_pattern), NULL,
 			&status);
 
-	status = 0;
-	fits_read_key(fit->fptr, TSTRING, "DATE-OBS", &(fit->date_obs), NULL,
-			&status);
+	read_fits_date_obs_header(fit);
 
 	status = 0;
 	fits_read_key(fit->fptr, TSTRING, "DATE", &(fit->date), NULL,
@@ -126,6 +142,9 @@ static void read_fits_header(fits *fit) {
 	fits_read_key(fit->fptr, TDOUBLE, "ISOSPEED", &(fit->iso_speed), NULL,
 			&status);	// Non-standard keywords used in MaxIm DL
 
+	status = 0;
+	fits_read_key(fit->fptr, TDOUBLE, "CVF", &(fit->cvf), NULL, &status);
+
 	/*******************************************************************
 	 * ************************* DFT KEYWORDS **************************
 	 * ****************************************************************/
@@ -159,7 +178,8 @@ int readfits(const char *filename, fits *fit, char *realname) {
 	long orig[3] = { 1L, 1L, 1L };
 	// orig ^ gives the coordinate in each dimension of the first pixel to be read
 	int zero = 0;
-	char name[256], *msg = NULL, *basename;
+	char *name = NULL, *msg = NULL;
+	gchar *basename;
 	image_type imagetype;
 	int i;
 	unsigned int nbdata;
@@ -168,12 +188,13 @@ int readfits(const char *filename, fits *fit, char *realname) {
 	unsigned long offset;
 	BYTE *data8;
 
-	fit->naxes[2] = 1; //initialization of the axis numer before opening : NEED TO BE OPTIMIZED
+	fit->naxes[2] = 1; //initialization of the axis number before opening : NEED TO BE OPTIMIZED
 
-	if (stat_file(filename, &imagetype, name)) {
+	if (stat_file(filename, &imagetype, &name)) {
 		msg = siril_log_message(_("%s.[any_allowed_extension] not found.\n"),
 				filename);
 		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		free(name);
 		return 1;
 	}
 	if (imagetype != TYPEFITS) {
@@ -181,6 +202,7 @@ int readfits(const char *filename, fits *fit, char *realname) {
 				_("The file %s is not a FITS file or doesn't exists with FITS extensions.\n"),
 						filename);
 		show_dialog(msg, _("Error"), "gtk-dialog-error");
+		free(name);
 		return 1;
 	}
 
@@ -190,8 +212,10 @@ int readfits(const char *filename, fits *fit, char *realname) {
 	fits_open_diskfile(&(fit->fptr), name, READONLY, &status);
 	if (status) {
 		report_fits_error(status);
+		free(name);
 		return status;
 	}
+	free(name);
 
 	status = 0;
 	fits_get_img_param(fit->fptr, 3, &(fit->bitpix), &(fit->naxis), fit->naxes,
@@ -436,11 +460,12 @@ void report_fits_error(int status) {
 /* Read a rectangular section of a FITS image in Siril's format, pointed by its
  * exact filename. Only layer layer is read. */
 int readfits_partial(const char *filename, int layer, fits *fit,
-		const rectangle *area) {
+		const rectangle *area, gboolean do_photometry) {
 	int status;
 	unsigned int nbdata;
 	long fpixel[3], lpixel[3], inc[3] = { 1L, 1L, 1L };
 	int zero = 0;
+	int dataType = TUSHORT;
 
 	status = 0;
 	if (fits_open_diskfile(&(fit->fptr), filename, READONLY, &status))
@@ -457,6 +482,18 @@ int readfits_partial(const char *filename, int layer, fits *fit,
 		fits_close_file(fit->fptr, &status);
 		return status;
 	}
+
+	status = 0;
+	fits_read_key(fit->fptr, TINT, "BZERO", &zero, NULL, &status);
+	if (fit->bitpix == SHORT_IMG && zero == 32768)
+		fit->bitpix = USHORT_IMG;
+
+	if (do_photometry) {
+		read_fits_date_obs_header(fit);
+		status = 0;
+		__tryToFindKeywords(fit->fptr, TDOUBLE, Exposure, &fit->exposure);
+
+	}
 	fit->rx = fit->naxes[0];	// size of the real image
 	fit->ry = fit->naxes[1];
 	if (fit->naxis == 2 && fit->naxes[2] == 0)
@@ -488,14 +525,24 @@ int readfits_partial(const char *filename, int layer, fits *fit,
 		fits_close_file(fit->fptr, &status);
 		return -1;
 	}
-	if (fit->bitpix != SHORT_IMG && fit->bitpix != USHORT_IMG
-			&& fit->bitpix != BYTE_IMG) {
-		siril_log_message(
-				_("Only Siril FITS images can be used with partial image reading.\n"));
+
+	switch (fit->bitpix) {
+	case SHORT_IMG:
+		dataType = TSHORT;
+		break;
+	case BYTE_IMG:
+		dataType = TBYTE;
+		break;
+	case USHORT_IMG:
+		dataType = TUSHORT;
+		break;
+	default:
+		siril_log_color_message(_("Only Siril FITS images "
+				"can be used with partial image reading.\n"), "red");
 		return -1;
 	}
 	fit->naxes[2] = 1;	// force to 1 layer
-	fit->bitpix = USHORT_IMG;
+	fit->bitpix = USHORT_IMG;	// force to be USHORT
 
 	/* realloc fit->data to the image size */
 	WORD *olddata = fit->data;
@@ -512,7 +559,7 @@ int readfits_partial(const char *filename, int layer, fits *fit,
 	fit->pdata[BLAYER] = fit->data;
 
 	status = 0;
-	fits_read_subset(fit->fptr, TUSHORT, fpixel, lpixel, inc, &zero, fit->data,
+	fits_read_subset(fit->fptr, dataType, fpixel, lpixel, inc, &zero, fit->data,
 			&zero, &status);
 	if (status) {
 		report_fits_error(status);
@@ -522,7 +569,7 @@ int readfits_partial(const char *filename, int layer, fits *fit,
 	}
 	status = 0;
 	fits_close_file(fit->fptr, &status);
-	siril_log_message(_("Loaded partial FITS file %s\n"), filename);
+	printf(_("Loaded partial FITS file %s\n"), filename);
 	return 0;
 }
 
@@ -587,6 +634,20 @@ int read_opened_fits_partial(sequence *seq, int layer, int index, WORD *buffer,
 	return 0;
 }
 
+int fits_get_date_obs(const char *name, fits *f) {
+	int status = 0;
+	if (fits_open_diskfile(&(f->fptr), name, READONLY, &status))
+		report_fits_error(status);
+	if (status)
+		return status;
+
+	read_fits_date_obs_header(f);
+
+	status = 0;
+	fits_close_file(f->fptr, &status);
+	return status;
+}
+
 /* creates, saves and closes the file associated to f, overwriting previous  */
 int savefits(const char *name, fits *f) {
 	int status, i;
@@ -615,6 +676,7 @@ int savefits(const char *name, fits *f) {
 		report_fits_error(status);
 		return 1;
 	}
+	status = 0;
 	if (fits_create_img(f->fptr, f->bitpix, f->naxis, f->naxes, &status)) {
 		report_fits_error(status);
 		return 1;
@@ -622,6 +684,7 @@ int savefits(const char *name, fits *f) {
 
 	pixel_count = f->naxes[0] * f->naxes[1] * f->naxes[2];
 
+	status = 0;
 	switch (f->bitpix) {
 	case BYTE_IMG:
 		data8 = calloc(pixel_count, sizeof(BYTE));
@@ -667,6 +730,7 @@ int savefits(const char *name, fits *f) {
 
 	if (!status)
 		save_fits_header(f);
+	status = 0;
 	fits_close_file(f->fptr, &status);
 	if (!status)
 		siril_log_message(_("Saving FITS: file %s, %ld layer(s), %ux%u pixels\n"),
@@ -790,6 +854,11 @@ void save_fits_header(fits *fit) {
 				"Y offset of Bayer array", &status);
 	}
 
+	status = 0;
+	if (fit->cvf > 0.)
+		fits_update_key(fit->fptr, TDOUBLE, "CVF", &(fit->cvf),
+				"Conversion factor (e-/adu)", &status);
+
 	/*******************************************************************
 	 * ******************** PROGRAMM KEYWORDS **************************
 	 * ****************************************************************/
