@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -674,8 +674,8 @@ static int _pic_read_header(struct pic_struct *pic_file) {
 	assert(pic_file->nbplane != 0);
 	memcpy(&pic_file->hi, header + 118, 2);
 	memcpy(&pic_file->lo, header + 120, 2);
-	pic_file->date = strndup(header + 94, 10);
-	pic_file->time = strndup(header + 104, 12);
+	pic_file->date = g_strndup(header + 94, 10);
+	pic_file->time = g_strndup(header + 104, 12);
 	return 0;
 }
 
