@@ -1,7 +1,7 @@
 /*
  * This file is part of Siril, an astronomy image processor.
  * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
- * Copyright (C) 2012-2016 team free-astro (see more in AUTHORS file)
+ * Copyright (C) 2012-2017 team free-astro (see more in AUTHORS file)
  * Reference site is https://free-astro.org/index.php/Siril
  *
  * Siril is free software: you can redistribute it and/or modify
@@ -37,6 +37,7 @@
 #include "core/proto.h"
 #include "core/initfile.h"
 #include "gui/callbacks.h"
+#include "io/sequence.h"
 #include "io/single_image.h"
 #include "registration/registration.h"
 #include "stacking/stacking.h"
@@ -374,6 +375,10 @@ int stack_median(struct stacking_args *args) {
 	int pool_size = 1;
 	fits *fit = &wfit[0];
 	norm_coeff coeff;
+	struct image_block {
+		unsigned long channel, start_row, end_row, height;
+	};
+	struct image_block *blocks = NULL;
 
 	nb_frames = args->nb_images_to_stack;
 
@@ -598,11 +603,8 @@ int stack_median(struct stacking_args *args) {
 	}
 	siril_log_message(_("We have %d parallel blocks of size %d (+%d) for stacking.\n"),
 			nb_parallel_stacks, size_of_stacks, remainder);
-	struct image_block {
-		unsigned long channel, start_row, end_row, height;
-	};
 	long largest_block_height = 0;
-	struct image_block *blocks = malloc(nb_parallel_stacks * sizeof(struct image_block));
+	blocks = malloc(nb_parallel_stacks * sizeof(struct image_block));
 	{
 		long channel = 0, row = 0, end, j = 0;
 		do {
@@ -796,6 +798,7 @@ free_and_close:
 		}
 		free(data_pool);
 	}
+	if (blocks) free(blocks);
 	free(coeff.offset);
 	free(coeff.mul);
 	free(coeff.scale);
@@ -886,8 +889,6 @@ int stack_addmax(struct stacking_args *args) {
 				final_pixel[1] = final_pixel[0] + nbdata;	// index of green layer in final_pixel[0]
 				final_pixel[2] = final_pixel[0] + nbdata*2;	// index of blue layer in final_pixel[0]
 			}
-			//~ siril_log_message("Stacking: successfully allocated memory for "
-					//~ "stacking operation\n");
 		} else if (fit->ry * fit->rx != nbdata) {
 			siril_log_message(_("Stacking: image in sequence doesn't has the same dimensions\n"));
 			retval = -3;
@@ -1202,6 +1203,7 @@ int stack_mean_with_rejection(struct stacking_args *args) {
 	int pool_size = 1;
 	fits *fit = &wfit[0];
 	norm_coeff coeff;
+	struct image_block *blocks = NULL;
 
 	nb_frames = args->nb_images_to_stack;
 	reglayer = get_registration_layer();
@@ -1431,7 +1433,7 @@ int stack_mean_with_rejection(struct stacking_args *args) {
 		unsigned long channel, start_row, end_row, height;
 	};
 	long largest_block_height = 0;
-	struct image_block *blocks = malloc(nb_parallel_stacks * sizeof(struct image_block));
+	blocks = malloc(nb_parallel_stacks * sizeof(struct image_block));
 	{
 		long channel = 0, row = 0, end, j = 0;
 		do {
@@ -1837,6 +1839,7 @@ free_and_close:
 		}
 		free(data_pool);
 	}
+	if (blocks) free(blocks);
 	free(coeff.offset);
 	free(coeff.mul);
 	free(coeff.scale);
